[−][src]Module chunked_bytes::loosely
Buffer with a loose adherence to the preferred chunk size.
Structs
| ChunkedBytes | A non-contiguous buffer for efficient serialization of data structures. |
Buffer with a loose adherence to the preferred chunk size.
| ChunkedBytes | A non-contiguous buffer for efficient serialization of data structures. |